# Changelog

## [Unreleased]

## [0.4.1] - 2025-05-30

* Rename image to fix reference in documentation

## [0.4.0] - 2025-05-30

* Complete list of keywords, functions and operators accoding to the
  [New Relic documentation](https://docs.newrelic.com/docs/nrql/nrql-syntax-clauses-functions/)
  and related links.

## [0.3.0] - 2025-04-08

* Fix error when using both `*` and `!=` operators.

## [0.2.0] - 2024-11-27

* Fix entrypoint name for the package

## [0.1.0] - 2024-11-27

* Add support for buil-in keywords
* Add support for buil-in functions
* Add support for buil-in operators
* Add support for regex expressions
